@@ -24,7 +24,7 @@ from typing import (
     overload,
 )
 
-import attr
+import attrs
 
 import trio
 from trio._util import NoPublicConstructor, final
@@ -83,7 +83,7 @@ def _scatter(data: bytes, buffers: Iterable[Buffer]) -> int:
 T_UDPEndpoint = TypeVar("T_UDPEndpoint", bound="UDPEndpoint")
 
 
-@attr.frozen
+@attrs.frozen
 class UDPEndpoint:
     ip: IPAddress
     port: int
@@ -105,17 +105,17 @@ class UDPEndpoint:
         return cls(ip=ipaddress.ip_address(ip), port=port)
 
 
-@attr.frozen
+@attrs.frozen
 class UDPBinding:
     local: UDPEndpoint
     # remote: UDPEndpoint # ??
 
 
-@attr.frozen
+@attrs.frozen
 class UDPPacket:
     source: UDPEndpoint
     destination: UDPEndpoint
-    payload: bytes = attr.ib(repr=lambda p: p.hex())
+    payload: bytes = attrs.field(repr=lambda p: p.hex())
 
     # not used/tested anywhere
     def reply(self, payload: bytes) -> UDPPacket:  # pragma: no cover
@@ -124,21 +124,21 @@ class UDPPacket:
         )
 
 
-@attr.frozen
+@attrs.frozen
 class FakeSocketFactory(trio.abc.SocketFactory):
     fake_net: FakeNet
 
-    def socket(self, family: int, type: int, proto: int) -> FakeSocket:  # type: ignore[override]
-        return FakeSocket._create(self.fake_net, family, type, proto)
+    def socket(self, family: int, type_: int, proto: int) -> FakeSocket:  # type: ignore[override]
+        return FakeSocket._create(self.fake_net, family, type_, proto)
 
 
-@attr.frozen
+@attrs.frozen
 class FakeHostnameResolver(trio.abc.HostnameResolver):
     fake_net: FakeNet
 
     async def getaddrinfo(
         self,
-        host: bytes | str | None,
+        host: bytes | None,
         port: bytes | str | int | None,
         family: int = 0,
         type: int = 0,
@@ -200,14 +200,18 @@ class FakeNet:
 @final
 class FakeSocket(trio.socket.SocketType, metaclass=NoPublicConstructor):
     def __init__(
-        self, fake_net: FakeNet, family: AddressFamily, type: SocketKind, proto: int
+        self,
+        fake_net: FakeNet,
+        family: AddressFamily,
+        type: SocketKind,
+        proto: int,
     ):
         self._fake_net = fake_net
 
         if not family:  # pragma: no cover
             family = trio.socket.AF_INET
         if not type:  # pragma: no cover
-            type = trio.socket.SOCK_STREAM
+            type = trio.socket.SOCK_STREAM  # noqa: A001  # name shadowing builtin
 
         if family not in (trio.socket.AF_INET, trio.socket.AF_INET6):
             raise NotImplementedError(f"FakeNet doesn't (yet) support family={family}")
@@ -405,12 +409,10 @@ class FakeSocket(trio.socket.SocketType, metaclass=NoPublicConstructor):
         _fake_err(errno.ENOTCONN)
 
     @overload
-    def getsockopt(self, /, level: int, optname: int) -> int:
-        ...
+    def getsockopt(self, /, level: int, optname: int) -> int: ...
 
     @overload
-    def getsockopt(self, /, level: int, optname: int, buflen: int) -> bytes:
-        ...
+    def getsockopt(self, /, level: int, optname: int, buflen: int) -> bytes: ...
 
     def getsockopt(
         self, /, level: int, optname: int, buflen: int | None = None
@@ -419,12 +421,12 @@ class FakeSocket(trio.socket.SocketType, metaclass=NoPublicConstructor):
         raise OSError(f"FakeNet doesn't implement getsockopt({level}, {optname})")
 
     @overload
-    def setsockopt(self, /, level: int, optname: int, value: int | Buffer) -> None:
-        ...
+    def setsockopt(self, /, level: int, optname: int, value: int | Buffer) -> None: ...
 
     @overload
-    def setsockopt(self, /, level: int, optname: int, value: None, optlen: int) -> None:
-        ...
+    def setsockopt(
+        self, /, level: int, optname: int, value: None, optlen: int
+    ) -> None: ...
 
     def setsockopt(
         self,
@@ -465,8 +467,7 @@ class FakeSocket(trio.socket.SocketType, metaclass=NoPublicConstructor):
     @overload
     async def sendto(
         self, __data: Buffer, __address: tuple[object, ...] | str | Buffer
-    ) -> int:
-        ...
+    ) -> int: ...
 
     @overload
     async def sendto(
@@ -474,8 +475,7 @@ class FakeSocket(trio.socket.SocketType, metaclass=NoPublicConstructor):
         __data: Buffer,
         __flags: int,
         __address: tuple[object, ...] | str | None | Buffer,
-    ) -> int:
-        ...
+    ) -> int: ...
 
     async def sendto(self, *args: Any) -> int:
         data: Buffer
